@@ -2,22 +2,22 @@ import argparse
 import sys
 from . import basketcase
 
-def parse():
+def main():
     parser = argparse.ArgumentParser(description='Fetch resources from Instagram.')
-    parser.add_argument('session_id', help='The session cookie id')
+    parser.add_argument('-c', '--cookie', help='The session cookie id')
     args = parser.parse_args()
 
-    urls = []
+    urls = set()
 
     for line in sys.stdin:
         line = line.rstrip()
 
         if (line):
-            urls.append(line)
+            urls.add(line)
 
-    bc = basketcase.BasketCase(args.session_id)
+    bc = basketcase.BasketCase(args.cookie)
     bc.fetch(urls)
 
 if __name__ == '__main__':
-    parse()
+    main()
 
